struct BlockVerifierRouter<S, V>where
S: Service<Request, Response = Response, Error = BoxError> + Send + Clone + 'static,
S::Future: Send + 'static,
V: Service<Request, Response = Response, Error = BoxError> + Send + Clone + 'static,
V::Future: Send + 'static,{
checkpoint: CheckpointVerifier<S>,
max_checkpoint_height: Height,
block: SemanticBlockVerifier<S, V>,
}Expand description
The block verifier router routes requests to either the checkpoint verifier or the semantic block verifier, depending on the maximum checkpoint height.
Correctness
Block verification requests should be wrapped in a timeout, so that
out-of-order and invalid requests do not hang indefinitely. See the router
module documentation for details.
Fields
checkpoint: CheckpointVerifier<S>The checkpointing block verifier.
Always used for blocks before Canopy, optionally used for the entire checkpoint list.
max_checkpoint_height: HeightThe highest permitted checkpoint block.
This height must be in the checkpoint verifier’s checkpoint list.
block: SemanticBlockVerifier<S, V>The full semantic block verifier, used for blocks after max_checkpoint_height.